==> owncloud-10.2.0.zip: owncloud/README.md <==
# ownCloud Core

[![Build Status](https://drone.owncloud.com/api/badges/owncloud/core/status.svg?branch=stable10)](https://drone.owncloud.com/owncloud/core)
[![codecov.io](https://codecov.io/github/owncloud/core/coverage.svg?branch=master)](https://codecov.io/github/owncloud/core?branch=master)

**[ownCloud](http://ownCloud.org) gives you freedom and control over your own data.
A personal cloud which runs on your own server.**

![](https://github.com/owncloud/screenshots/blob/master/files/sidebar_1.png)

## Why is this so awesome?
* :file_folder: **Access your Data** You can store your files, contacts, calendars and more on a server of your choosing.
* :package: **Sync your Data** You keep your files, contacts, calendars and more synchronized amongst your devices.
* :arrows_counterclockwise: **Share your Data** You share your data with others, and give them access to your latest photo galleries, your calendar or anything else you want them to see.
* :rocket: **Expandable with dozens of Apps** ...like Calendar, Contacts, Mail or News.
* :cloud: **All Benefits of the Cloud** ...on your own Server.
* :lock: **Encryption** You can encrypt data in transit with secure https connections. You can enable the encryption app to encrypt data on storage for improved security and privacy.
* ...

## Installation instructions
https://doc.owncloud.org/server/10.2/admin_manual/installation/

## Contribution Guidelines
https://owncloud.org/contribute/

## Support
Learn about the different ways you can get support for ownCloud: https://owncloud.org/support/

## Get in touch
* :clipboard: [Forum](https://central.owncloud.org)
* :envelope: [Mailing list](https://mailman.owncloud.org/mailman/listinfo)
* :hash: [IRC channel](https://webchat.freenode.net/?channels=owncloud)
* :busts_in_silhouette: [Facebook](https://facebook.com/ownclouders)
* :hatching_chick: [Twitter](https://twitter.com/ownClouders)

## Important notice on translations
Please submit translations via Transifex:
https://www.transifex.com/projects/p/owncloud/

For detailed information about translations:
https://doc.owncloud.org/server/10.2/developer_manual/core/translation.html

==> owncloud-10.4.0.zip: owncloud/README.md <==
# ownCloud Core

[![Build Status](https://drone.owncloud.com/api/badges/owncloud/core/status.svg?branch=master)](https://drone.owncloud.com/owncloud/core)
[![codecov.io](https://codecov.io/github/owncloud/core/coverage.svg?branch=master)](https://codecov.io/github/owncloud/core?branch=master)

**[ownCloud](http://ownCloud.org) gives you freedom and control over your own data.
A personal cloud which runs on your own server.**

![](https://github.com/owncloud/screenshots/blob/master/files/sidebar_1.png)

## Why is this so awesome?
* :file_folder: **Access your Data** You can store your files, contacts, calendars and more on a server of your choosing.
* :package: **Sync your Data** You keep your files, contacts, calendars and more synchronized amongst your devices.
* :arrows_counterclockwise: **Share your Data** You share your data with others, and give them access to your latest photo galleries, your calendar or anything else you want them to see.
* :rocket: **Expandable with dozens of Apps** ...like Calendar, Contacts, Mail or News.
* :cloud: **All Benefits of the Cloud** ...on your own Server.
* :lock: **Encryption** You can encrypt data in transit with secure https connections. You can enable the encryption app to encrypt data on storage for improved security and privacy.
* ...

## Installation instructions
https://doc.owncloud.org/server/10.4/admin_manual/installation/

## Contribution Guidelines
https://owncloud.org/contribute/

## Support
Learn about the different ways you can get support for ownCloud: https://owncloud.org/support/

## Get in touch
* :clipboard: [Forum](https://central.owncloud.org)
* :envelope: [Mailing list](https://mailman.owncloud.org/mailman/listinfo)
* :hash: [IRC channel](https://webchat.freenode.net/?channels=owncloud)
* :busts_in_silhouette: [Facebook](https://facebook.com/ownclouders)
* :hatching_chick: [Twitter](https://twitter.com/ownClouders)

## Important notice on translations
Please submit translations via Transifex:
https://www.transifex.com/projects/p/owncloud/

For detailed information about translations:
https://doc.owncloud.org/server/10.4/developer_manual/core/translation.html
